==> paraselene-2.0.0.src.tar.gz: paraselene-2.0.0/paraselene/mockup/Converter.java <==
/*
 * Paraselene
 * Copyright (c) 2009  Akira Terasaki
 * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
 * 利用可能です。
 */
package paraselene.mockup;

import java.util.*;
import paraselene.*;
import paraselene.tag.*;
import paraselene.css.*;
import paraselene.supervisor.*;

public class Converter {

	private static String[] uri_name = new String[] {
		"href", "codebase", "src", "cite", "action", "profile", "background",
		"code", "data",
	};
	private static String[] clr_name = new String[] {
		"color", "bgcolor", "text", "link", "vlink", "alink",
		"bordercolor", "bordercolordark", "bordercolorlight",
	};
	private static String[]	len_name = new String[] {
		"height", "hspace", "vspace", "width", "size", "units", "tabindex",
		"marginheight", "marginwidth", "topmargin", "leftmargin", "bottommargin",
		"rightmargin", "border", "framespacing",
		"charoff", "span", "colspan", "rowspan",
		"left", "pagex", "pagey", "top", "z-index", "loop",
		"scrollamount", "scrolldelay",
		"cols", "gutter",
		"cellpadding", "cellspacing", "datapagesize",
		"maxlength", "rows",
	};
	private static HashMap<String,String>	uri_map = new HashMap<String,String>();
	private static HashMap<String,String>	len_map = new HashMap<String,String>();
	private static HashMap<String,String>	clr_map = new HashMap<String,String>();
	static {
		for ( int i = 0; i < uri_name.length; i++ ) {
			uri_map.put( uri_name[i], uri_name[i] );
		}
		for ( int i = 0; i < len_name.length; i++ ) {
			len_map.put( len_name[i], len_name[i] );
		}
		for ( int i = 0; i < clr_name.length; i++ ) {
			clr_map.put( clr_name[i], clr_name[i] );
		}
	}

	/**
	 * URI属性であるか？
	 * @param n 属性名。
	 * @return true:URI属性、false:URI属性ではない。
	 */
	static boolean isURI( String n ) {
		return ( uri_map.get( n.toLowerCase( Locale.ENGLISH ) ) != null );
	}
	/**
	 * 値を表す属性であるか？
	 * @param n 属性名。
	 * @return true:値を表す、false:値ではない。
	 */
	static boolean isNumber( String n ) {
		return ( len_map.get( n.toLowerCase( Locale.ENGLISH ) ) != null );
	}
	/**
	 * 色属性であるか？
	 * @param n 属性名。
	 * @return true:色属性、false:色属性ではない。
	 */
	static boolean isColor( String n ) {
		return ( clr_map.get( n.toLowerCase( Locale.ENGLISH ) ) != null );
	}
	static boolean isStyle( String n ) {
		return "style".equals( n.toLowerCase( Locale.ENGLISH ) );
	}

	public static AttributeValuable toAttributeValuable( String name, Valuable v ) {
		AttributeValuable	txt = toAttributeValuable( v );
		if ( txt == null )	return null;
		if ( isURI( name ) ) {
			if ( txt instanceof URIValue )	return txt;
			try {
				return new URIValue( txt.toString() );
			}
			catch( Exception e ) {
				Option.debug( e );
			}
		}
		else if ( isNumber( name ) ) {
			if ( txt instanceof NumberValue )	return txt;
			return new NumberValue( txt.toString() );
		}
		else if ( isColor( name ) ) {
			if ( txt instanceof Color )	return txt;
			return new Color( txt.toString() );
		}
		else if ( isStyle( name ) ) {
			if ( txt instanceof Style )	return txt;
			return new Style( Property.create( txt.toString() ) );
		}
		return txt;
	}

	public static AttributeValuable toAttributeValuable( String name, String txt ) {
		if ( txt == null )	return null;
		if ( isURI( name ) ) {
			try {
				return new URIValue( txt );
			}
			catch( Exception e ) {
				Option.debug( e );
			}
		}
		else if ( isNumber( name ) ) {
			return new NumberValue( txt );
		}
		else if ( isColor( name ) ) {
			return new Color( txt );
		}
		else if ( isStyle( name ) ) {
			return new Style( Property.create( txt ) );
		}
		return new Text( txt );
	}

	private static AttributeValuable toAttributeValuable( Valuable v ) {
		if ( v == null )	return null;
		if ( v instanceof WebColor ) {
			return new Color( ((WebColor)v).toString() );
		}
		if ( v instanceof Infinite ) {
			return new NumberValue( (Infinite)v );
		}
		if ( v instanceof AttributeValuable ) {
			return (AttributeValuable)v;
		}
		Option.debug( "unknown class " + v.getClass().toString() );
		return null;
	}

	private static CSSValuable toCSSValuable( Valuable v ) {
		AttributeValuable	atb = toAttributeValuable( v );
		if ( atb == null )	return null;
		if ( atb instanceof CSSValuable ) {
			return (CSSValuable)atb;
		}
		Option.debug( "unknown class " + v.getClass().toString() );
		return null;
	}

	public static CSSValuable[] toCSSValuable( Valuable[] v ) {
		if ( v == null )	return new CSSValuable[0];
		ArrayList<CSSValuable>	ret = new ArrayList<CSSValuable>();
		for ( int i = 0; i < v.length; i++ ) {
			CSSValuable	tmp = toCSSValuable( v[i] );
			if ( tmp != null )	ret.add( tmp );
		}
		return ret.toArray( new CSSValuable[0] );
	}
}

==> paraselene-2.0.1.1.src.tar.gz: paraselene-2.0.1.1/paraselene/mockup/Converter.java <==
/*
 * Paraselene
 * Copyright (c) 2009  Akira Terasaki
 * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
 * 利用可能です。
 */
package paraselene.mockup;

import java.util.*;
import java.net.*;
import paraselene.*;
import paraselene.tag.*;
import paraselene.css.*;
import paraselene.supervisor.*;

public class Converter {

	private static String[] uri_name = new String[] {
		"href", "codebase", "src", "cite", "action", "profile", "background",
		"code", "data",
	};
	private static String[] clr_name = new String[] {
		"color", "bgcolor", "text", "link", "vlink", "alink",
		"bordercolor", "bordercolordark", "bordercolorlight",
	};
	private static String[]	len_name = new String[] {
		"height", "hspace", "vspace", "width", "size", "units", "tabindex",
		"marginheight", "marginwidth", "topmargin", "leftmargin", "bottommargin",
		"rightmargin", "border", "framespacing",
		"charoff", "span", "colspan", "rowspan",
		"left", "pagex", "pagey", "top", "z-index", "loop",
		"scrollamount", "scrolldelay",
		"cols", "gutter",
		"cellpadding", "cellspacing", "datapagesize",
		"maxlength", "rows",
	};
	private static HashMap<String,String>	uri_map = new HashMap<String,String>();
	private static HashMap<String,String>	len_map = new HashMap<String,String>();
	private static HashMap<String,String>	clr_map = new HashMap<String,String>();
	static {
		for ( int i = 0; i < uri_name.length; i++ ) {
			uri_map.put( uri_name[i], uri_name[i] );
		}
		for ( int i = 0; i < len_name.length; i++ ) {
			len_map.put( len_name[i], len_name[i] );
		}
		for ( int i = 0; i < clr_name.length; i++ ) {
			clr_map.put( clr_name[i], clr_name[i] );
		}
	}

	/**
	 * URI属性であるか？
	 * @param n 属性名。
	 * @return true:URI属性、false:URI属性ではない。
	 */
	static boolean isURI( String n ) {
		return ( uri_map.get( n.toLowerCase( Locale.ENGLISH ) ) != null );
	}
	/**
	 * 値を表す属性であるか？
	 * @param n 属性名。
	 * @return true:値を表す、false:値ではない。
	 */
	static boolean isNumber( String n ) {
		return ( len_map.get( n.toLowerCase( Locale.ENGLISH ) ) != null );
	}
	/**
	 * 色属性であるか？
	 * @param n 属性名。
	 * @return true:色属性、false:色属性ではない。
	 */
	static boolean isColor( String n ) {
		return ( clr_map.get( n.toLowerCase( Locale.ENGLISH ) ) != null );
	}
	static boolean isStyle( String n ) {
		return "style".equals( n.toLowerCase( Locale.ENGLISH ) );
	}

	public static AttributeValuable toAttributeValuable( String name, Valuable v, String dec ) {
		AttributeValuable	txt = toAttributeValuable( v );
		if ( txt == null )	return null;
		if ( isURI( name ) ) {
			if ( txt instanceof URIValue )	return txt;
			try {
				return new URIValue( txt.toString() );
			}
			catch( Exception e ) {
				Option.debug( e );
			}
		}
		else if ( isNumber( name ) ) {
			if ( txt instanceof NumberValue )	return txt;
			return new NumberValue( txt.toString() );
		}
		else if ( isColor( name ) ) {
			if ( txt instanceof Color )	return txt;
			return new Color( txt.toString() );
		}
		else if ( isStyle( name ) ) {
			if ( txt instanceof Style )	return txt;
			return new Style( Property.create( txt.toString(), dec ) );
		}
		return txt;
	}

	public static AttributeValuable toAttributeValuable( String name, String txt, String dec ) {
		if ( txt == null )	return null;
		if ( isURI( name ) ) {
			try {
				return new URIValue( txt );
			}
			catch( Exception e ) {
				Option.debug( e );
			}
		}
		else if ( isNumber( name ) ) {
			return new NumberValue( txt );
		}
		else if ( isColor( name ) ) {
			return new Color( txt );
		}
		else if ( isStyle( name ) ) {
			return new Style( Property.create( txt, dec ) );
		}
		return new Text( txt );
	}

	private static AttributeValuable toAttributeValuable( Valuable v ) {
		if ( v == null )	return null;
		if ( v instanceof WebColor ) {
			return new Color( ((WebColor)v).toString() );
		}
		if ( v instanceof Infinite ) {
			return new NumberValue( (Infinite)v );
		}
		if ( v instanceof AttributeValuable ) {
			return (AttributeValuable)v;
		}
		Option.debug( "unknown class " + v.getClass().toString() );
		return null;
	}

	public static CSSValuable toCSSValuable( String txt, String dec ) {
		try {
			return new Color( txt );
		}
		catch( Exception e ){}
		try {
			return new NumberValue( txt );
		}
		catch( Exception e ){}
		if ( URIValue.isCSSURL( txt ) ) {
			txt = URIValue.CSSURLStrip( txt );
			try {
				return new URIValue( new URI( txt ), dec, null );
			}
			catch( Exception e ){
				try {
					return new URIValue( txt );
				}
				catch( Exception ee ) {
					Option.debug( ee );
				}
			}
		}
		return new Text( txt );
	}

	private static CSSValuable toCSSValuable( Valuable v ) {
		AttributeValuable	atb = toAttributeValuable( v );
		if ( atb == null )	return null;
		if ( atb instanceof CSSValuable ) {
			return (CSSValuable)atb;
		}
		Option.debug( "unknown class " + v.getClass().toString() );
		return null;
	}

	public static CSSValuable[] toCSSValuable( Valuable[] v ) {
		if ( v == null )	return new CSSValuable[0];
		ArrayList<CSSValuable>	ret = new ArrayList<CSSValuable>();
		for ( int i = 0; i < v.length; i++ ) {
			CSSValuable	tmp = toCSSValuable( v[i] );
			if ( tmp != null )	ret.add( tmp );
		}
		return ret.toArray( new CSSValuable[0] );
	}
}
